==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/ScatterSplineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ScatterBaseDescriptionMetadata } from "./ScatterBaseDescriptionMetadata";
import { ScatterSplineSeriesDescription } from "./ScatterSplineSeriesDescription";
/**
 * @hidden
 */
var ScatterSplineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ScatterSplineSeriesDescriptionMetadata, _super);
    function ScatterSplineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ScatterSplineSeriesDescriptionMetadata.b = function (a) {
        if (ScatterSplineSeriesDescriptionMetadata.a == null) {
            ScatterSplineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ScatterSplineSeriesDescriptionMetadata.c(ScatterSplineSeriesDescriptionMetadata.a);
        }
        if (a.j(ScatterSplineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(ScatterSplineSeriesDescriptionMetadata.a);
    };
    ScatterSplineSeriesDescriptionMetadata.c = function (a) {
        ScatterBaseDescriptionMetadata.c(a);
        a.item("Stiffness", "Number:double");
    };
    ScatterSplineSeriesDescriptionMetadata.d = function (a) {
        ScatterSplineSeriesDescriptionMetadata.b(a);
        a.aa("ScatterSplineSeries", function () { return new ScatterSplineSeriesDescription(); });
        a.z("ScatterSplineSeries", ScatterSplineSeriesDescriptionMetadata.a);
    };
    ScatterSplineSeriesDescriptionMetadata.$t = markType(ScatterSplineSeriesDescriptionMetadata, 'ScatterSplineSeriesDescriptionMetadata');
    ScatterSplineSeriesDescriptionMetadata.a = null;
    return ScatterSplineSeriesDescriptionMetadata;
}(Base));
export { ScatterSplineSeriesDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/ScatterSplineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ScatterBaseDescriptionMetadata } from "./ScatterBaseDescriptionMetadata";
import { ScatterSplineSeriesDescription } from "./ScatterSplineSeriesDescription";
/**
 * @hidden
 */
var ScatterSplineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ScatterSplineSeriesDescriptionMetadata, _super);
    function ScatterSplineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ScatterSplineSeriesDescriptionMetadata.b = function (a) {
        if (ScatterSplineSeriesDescriptionMetadata.a == null) {
            ScatterSplineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ScatterSplineSeriesDescriptionMetadata.c(ScatterSplineSeriesDescriptionMetadata.a);
        }
        if (a.k(ScatterSplineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.aa(ScatterSplineSeriesDescriptionMetadata.a);
    };
    ScatterSplineSeriesDescriptionMetadata.c = function (a) {
        ScatterBaseDescriptionMetadata.c(a);
        a.item("Stiffness", "Number:double");
    };
    ScatterSplineSeriesDescriptionMetadata.d = function (a) {
        ScatterSplineSeriesDescriptionMetadata.b(a);
        a.ac("ScatterSplineSeries", function () { return new ScatterSplineSeriesDescription(); });
        a.ab("ScatterSplineSeries", ScatterSplineSeriesDescriptionMetadata.a);
    };
    ScatterSplineSeriesDescriptionMetadata.$t = markType(ScatterSplineSeriesDescriptionMetadata, 'ScatterSplineSeriesDescriptionMetadata');
    ScatterSplineSeriesDescriptionMetadata.a = null;
    return ScatterSplineSeriesDescriptionMetadata;
}(Base));
export { ScatterSplineSeriesDescriptionMetadata };
